@@ -1,25 +1,9 @@
 /*
     This file is part of Akregator.
 
-    Copyright (C) 2004 Sashmit Bhaduri <smt@vfemail.net>
+    SPDX-FileCopyrightText: 2004 Sashmit Bhaduri <smt@vfemail.net>
 
-    This program is free software; you can redistribute it and/or modify
-    it under the terms of the GNU General Public License as published by
-    the Free Software Foundation; either version 2 of the License, or
-    (at your option) any later version.
-
-    This program is distributed in the hope that it will be useful,
-    but WITHOUT ANY WARRANTY; without even the implied warranty of
-    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
-    GNU General Public License for more details.
-
-    You should have received a copy of the GNU General Public License
-    along with this program; if not, write to the Free Software
-    Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
-
-    As a special exception, permission is given to link this program
-    with any edition of Qt, and distribute the resulting executable,
-    without including the source code for Qt in the source distribution.
+    SPDX-License-Identifier: GPL-2.0-or-later WITH Qt-Commercial-exception-1.0
 */
 
 #include "frame.h"
@@ -35,11 +19,6 @@ Frame::Frame(QWidget *parent)
     : QWidget(parent)
 {
     m_title = i18n("Untitled");
-    m_state = Idle;
-    m_progress = -1;
-    m_progressItem = nullptr;
-    m_isRemovable = true;
-    m_loading = false;
     m_id = m_idCounter++;
 }
 
